//
//  PlayerViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/10/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit
import AVFoundation

class PlayerViewController: UIViewController, AVAudioPlayerDelegate {
    @IBOutlet weak var fileNameLabel: UILabel!
    @IBOutlet weak var playButton: UIButton!
    @IBOutlet weak var stopButton: UIButton!
    @IBOutlet weak var slider: UISlider!
    @IBOutlet weak var elapseTimeLabel: UILabel!    // Left label
    @IBOutlet weak var remainingTimeLabel: UILabel! // Right label
    
    var selectedAudioFileName: String!
    var selectedAudioUrl: NSURL!
    var timer: NSTimer!
    var audioPlayer: AVAudioPlayer?

    override func viewDidLoad() {
        super.viewDidLoad()
        fileNameLabel.text = selectedAudioFileName
        audioPlayer = nil
        audioPlayer = AVAudioPlayer(contentsOfURL: selectedAudioUrl, error: nil)
        audioPlayer?.delegate = self
        slider.minimumValue = 0.00
        slider.maximumValue = Float(audioPlayer!.duration)
        updateDisplay()
    }
    
    override func viewWillDisappear(animated: Bool) {
        if timer != nil {
            stopTimer()
            audioPlayer?.stop()
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    override func prefersStatusBarHidden() -> Bool {
        return true
    }
    
    @IBAction func playButtonTapped() {
        audioPlayer?.play()
        
        // Start the timer, which animates the sliderView
        timer = NSTimer.scheduledTimerWithTimeInterval(0.1,
            target:self,
            selector:"timerFired",
            userInfo:nil,
            repeats:true)
    }
    
    @IBAction func pauseButtonTapped() {
        audioPlayer?.pause()
        stopTimer()
        updateDisplay()
    }
    
    @IBAction func stopButtonTapped() {
        audioPlayer?.stop()
        stopTimer()
        audioPlayer?.currentTime = 0
        updateDisplay()
    }
   
    @IBAction func currentTimeSliderValueChanged(sender: AnyObject) {
        if (timer != nil) {
            stopTimer()
        }
        updateSliderLabels()
    }
    
    @IBAction func currentTimeSliderTouchUpInside(sender: AnyObject) {
        audioPlayer?.stop()
        audioPlayer?.currentTime = NSTimeInterval(slider.value)
        audioPlayer?.prepareToPlay()
        self.playButtonTapped().self
    }
    
    // MARK: - Display update functions (2)
    
    func updateDisplay() {
        var currentTime: NSTimeInterval = audioPlayer!.currentTime
        var currentTimeString:NSString = NSString(format:"%.02f", currentTime)
        
        slider.value = Float(currentTime)
        updateSliderLabels()
    }
    
    func updateSliderLabels() {
        var currentTime: NSTimeInterval = NSTimeInterval(slider.value)
        var currentTimeString = NSString(format: "%.02f", currentTime)
        
        elapseTimeLabel.text = currentTimeString as String
        remainingTimeLabel.text = NSString(format: "%.02f", audioPlayer!.duration - currentTime) as String
    }
    
    // MARK: - Timer functions (2)
    
    func timerFired() {
        updateDisplay()
    }
    
    func stopTimer() {
        if timer != nil {
            timer.invalidate()
        }
        timer = nil
        updateDisplay()
    }
    
    // MARK: - AVAudioPlayerDelegate functions (2)
    
    func audioPlayerDidFinishPlaying(player: AVAudioPlayer!, successfully flag: Bool) {
        stopTimer()
        updateDisplay()
        
        var alert: UIAlertView = UIAlertView()
        alert.title = "Audio Player"
        alert.message = "Sound finished playing"
        alert.addButtonWithTitle("Dismiss")
        alert.show()
    }
    
    func audioPlayerDecodeErrorDidOccur(player: AVAudioPlayer!, error: NSError!) {
        stopTimer()
        updateDisplay()
    }
    
}
