//
//  RecorderViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/4/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit
import AVFoundation

class RecorderViewController: UIViewController, AVAudioRecorderDelegate {
    @IBOutlet weak var recordButton: UIButton!
    @IBOutlet weak var stopButton: UIButton!
    @IBOutlet weak var progressView: UIProgressView!
    
    var progressCounter: Float = 0.00
    var progressViewTimer: NSTimer!
    var soundFileName: String!
    var audioRecorder: AVAudioRecorder?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = UIColor(patternImage: UIImage(named:"wallpaper2.png")!)
        progressView?.tintColor = UIColor(red: 1.0, green: 0.02, blue: 0.00, alpha: 1.0)
        progressView?.progress = progressCounter
        stopButton?.enabled = false
        
        /*** DEBUG STATEMENT ***/
        println("DocumentsDirPath:\n\(fetchDocDir())")
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }

    @IBAction func recordButtonClicked() {
        stopButton.enabled = true
        progressCounter = 0.0
        createOverwriteAudioFile()
        audioRecorder?.record()
        
        if progressViewTimer != nil {
            progressViewTimer.invalidate()
        }
        
        progressViewTimer = NSTimer.scheduledTimerWithTimeInterval(0.1,
            target:self,
            selector:"updateProgressView",
            userInfo:nil,
            repeats:true)
    }
    
    func updateProgressView() {
        progressCounter += 0.01
        progressView.progress = progressCounter
        
        if progressCounter > 1.0 {
            progressViewTimer.invalidate()
        }
        
        /*** DEBUG STATEMENT ***/
        println("Progress: \(progressCounter)")
    }
    
    func createOverwriteAudioFile() {
        var format = NSDateFormatter()
        format.dateFormat = "yyyy-dd-MMM-hhmmss"
        let currentDate = NSDate()
        soundFileName = "auidio-\(format.stringFromDate(currentDate)).m4a"
        let dirPaths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        let docsDir: AnyObject = dirPaths[0]
        let soundFilePath = docsDir.stringByAppendingPathComponent(soundFileName)
        let soundFileUrl = NSURL(fileURLWithPath: soundFilePath)
        
        var recordSettings = [
            AVFormatIDKey: kAudioFormatAppleLossless,
            AVEncoderAudioQualityKey : AVAudioQuality.Max.rawValue,
            AVEncoderBitRateKey : 320000,
            AVNumberOfChannelsKey: 2,
            AVSampleRateKey : 44100.0
        ]
        
        audioRecorder = AVAudioRecorder(URL: soundFileUrl, settings: recordSettings as [NSObject : AnyObject], error: nil)
        audioRecorder?.delegate = self
        audioRecorder?.prepareToRecord()
        
        /*** DEBUG STATEMENT ***/
        println("\n\(soundFileName)")
    }
    
    @IBAction func stopButtonClicked() {
        audioRecorder?.stop()
        progressViewTimer.invalidate()
        progressView.progress = 0.0
        audioRecorder = nil
    }

    // Fetch and return the sandbox's Documents directory to its caller
    func fetchDocDir() -> String {
        let paths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true) as NSArray
        let documentsDir = paths.firstObject as! String
        return documentsDir
    }
    
    // MARK: - AVAudioRecorder delegates
    
    func audioRecorderDidFinishRecording(recorder: AVAudioRecorder!, successfully flag: Bool) {
        let msg = "Your recording was saved as, \(soundFileName)"
        let alert = UIAlertController(title: "Audio Diary", message: msg, preferredStyle: .Alert)
        alert.addAction(UIAlertAction(title: "OK", style: .Default, handler: nil))
        self.presentViewController(alert, animated: true, completion: nil)
        //self.navigationController?.dismissViewControllerAnimated(true, completion: nil)
    }
    
    func audioRecorderEncodeErrorDidOccur(recorder: AVAudioRecorder!, error: NSError!) {
        println("\(error.localizedDescription)")
    }
}
