//
//  RecordingsViewController.swift
//  AudioDiary
//
//  Created by Merlyn on 3/4/15.
//  Copyright (c) 2015 The App Lady. All rights reserved.
//

import UIKit

class RecordingsViewController: UITableViewController {
    var tableDataSource = [String]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = UIColor(patternImage: UIImage(named:"wallpaper1.jpg")!)
        tableView.tableFooterView = UIView(frame:CGRectZero)
        tableView.separatorColor = UIColor.clearColor()
        fetchSoundFiles()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }
    
    // MARK: - Table view data source functions (5)
    
    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        // Return the number of sections.
        return 1
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // Return the number of rows in the section.
        return tableDataSource.count
    }
    
    // This function configure and display content in the table view cells
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath) as! UITableViewCell
        
        cell.backgroundColor = UIColor(red:1.00, green:0.80, blue:0.60, alpha:1.00)
        cell.imageView!.image = UIImage(named:"audio-file-32")
        cell.textLabel!.text = tableDataSource[indexPath.row]
        cell.backgroundColor = UIColor.clearColor()
        
        // Return the configured cell
        return cell
    }
    
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            let soundFileToDelete = self.tableDataSource[indexPath.row]
            self.deleteAudioFile(soundFileToDelete)
            tableDataSource.removeAtIndex(indexPath.row)
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
            tableView.reloadData()
        }
    }
    
    // MARK: - Data model functions (3)
    
    func fetchDocDir() -> String {
        let paths = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true) as NSArray
        let documentsDir = paths.firstObject as! String
        return documentsDir
    }
    
    func fetchSoundFiles() {
        let soundFileExtensions = ["mp4", "m4a", "caf", "mp3"]
        let fileManager = NSFileManager.defaultManager()
        var files = fileManager.contentsOfDirectoryAtPath(fetchDocDir(), error: nil)!
        var counter = 0
        
        for var i = 0; i < files.count; i++ {
            let file: String = files[i] as! String
            let currentExt = file.pathExtension
            if contains(soundFileExtensions, currentExt) {
                tableDataSource.append(file)
                counter++
            }
        }
    }

    func deleteAudioFile(soundFileToDelete: String) {
        var docsDir: String = fetchDocDir()
        var soundFilePath = docsDir.stringByAppendingPathComponent(soundFileToDelete)
        
        let fileManager = NSFileManager.defaultManager()
        if fileManager.fileExistsAtPath(soundFilePath) {
            var error: NSError?
            if !fileManager.removeItemAtPath(soundFilePath, error: &error) {
                println("Failed to delete the sound file:\(error!.localizedDescription)")
            }
        }
    }
    
    // MARK: - Navigation
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if segue.identifier == "showPlayer" {
            if let indexPath = self.tableView.indexPathForSelectedRow() {
                let soundFile = self.tableDataSource[indexPath.row]
                let pathDir: String = fetchDocDir().stringByAppendingPathComponent(soundFile)
                let url = NSURL(fileURLWithPath: pathDir)
                var controller = (segue.destinationViewController as! UINavigationController).topViewController as! PlayerViewController
                
                controller.selectedAudioUrl = url
                controller.selectedAudioFileName = soundFile
            }
        }
    }

}
